import { ImpactHapticFeedback, NotificationHapticFeedback, SelectionHapticFeedback } from './haptic';
import { PopupParams } from './popup';
import { EventNames, EventParams, IsNever } from 'twa-core';
import { PopupClosedPayload, ThemeChangedPayload, ViewportChangedPayload } from './listening';
/**
 * Describes post-available event options.
 */
interface EventOptions<Params = never, Result = never> {
    /**
     * List of required parameters.
     */
    params: EventParams<IsNever<Params> extends true ? never : [Params]>;
    /**
     * Information about result in case, event can be awaited.
     */
    result: Result;
}
/**
 * Describes list of events and their parameters that could be posted by
 * Bridge.
 */
export interface BridgePostEventsMap {
    /**
     * Notifies parent iframe about current frame is ready.
     */
    iframe_ready: EventOptions;
    /**
     * Closes WebApp.
     */
    web_app_close: EventOptions;
    /**
     * Sends data to bot.
     */
    web_app_data_send: EventOptions<{
        data: string;
    }>;
    /**
     * Expands WebApp.
     */
    web_app_expand: EventOptions;
    /**
     * Opens link in default browser. Doesn't close application.
     */
    web_app_open_link: EventOptions<{
        url: string;
    }>;
    /**
     * Opens link which has format like "https://t.me/*".
     */
    web_app_open_tg_link: EventOptions<{
        path_full: string;
    }>;
    /**
     * Opens new popup.
     */
    web_app_open_popup: EventOptions<PopupParams, PopupClosedPayload>;
    /**
     * Opens new invoice.
     */
    web_app_open_invoice: EventOptions<{
        slug: string;
    }>;
    /**
     * Notifies Telegram about current application is ready to be shown.
     */
    web_app_ready: EventOptions;
    /**
     * Requests current theme from Telegram.
     */
    web_app_request_theme: EventOptions<never, ThemeChangedPayload>;
    /**
     * Requests current viewport information from Telegram.
     */
    web_app_request_viewport: EventOptions<never, ViewportChangedPayload>;
    /**
     * Updates current information about back button.
     */
    web_app_setup_back_button: EventOptions<{
        is_visible: boolean;
    }>;
    /**
     * Updates current information about main button.
     */
    web_app_setup_main_button: EventOptions<{
        is_visible?: boolean;
        is_active?: boolean;
        is_progress_visible?: boolean;
        text?: string;
        color?: string;
        text_color?: string;
    }>;
    /**
     * Changes current closing confirmation requirement status.
     */
    web_app_setup_closing_behavior: EventOptions<{
        need_confirmation: boolean;
    }>;
    /**
     * Updates current background color.
     */
    web_app_set_background_color: EventOptions<{
        color: string;
    }>;
    /**
     * Updates current header color.
     */
    web_app_set_header_color: EventOptions<{
        color_key: string;
    }>;
    /**
     * Generates haptic feedback events.
     */
    web_app_trigger_haptic_feedback: EventOptions<ImpactHapticFeedback | NotificationHapticFeedback | SelectionHapticFeedback>;
}
/**
 * Any post-available event name.
 */
export declare type BridgePostEventName = EventNames<BridgePostEventsMap>;
/**
 * Any post-available event name which does not require arguments.
 */
export declare type BridgePostEmptyEventName = {
    [E in BridgePostEventName]: BridgePostEventsMap[E]['params'] extends [] ? E : never;
}[BridgePostEventName];
/**
 * Any post-available event name which require arguments.
 */
export declare type BridgePostNonEmptyEventName = Exclude<BridgePostEventName, BridgePostEmptyEventName>;
/**
 * Any post-available event name which could be awaited.
 */
export declare type BridgePostAwaitEventName = {
    [E in BridgePostEventName]: IsNever<BridgePostEventsMap[E]['result']> extends true ? never : E;
}[BridgePostEventName];
/**
 * Any post-available event name which could be awaited and does not require
 * arguments to call.
 */
export declare type BridgePostAwaitEmptyEventName = Extract<BridgePostAwaitEventName, BridgePostEmptyEventName>;
/**
 * Any post-available event name which could be awaited and requires
 * arguments to call.
 */
export declare type BridgePostAwaitNonEmptyEventName = Exclude<BridgePostAwaitEventName, BridgePostAwaitEmptyEventName>;
/**
 * Returns arguments for specified post-available event.
 */
export declare type BridgePostEventArgs<E extends BridgePostEventName> = BridgePostEventsMap[E];
/**
 * Returns post-available event await result.
 */
export declare type BridgePostAwaitEventResult<E extends BridgePostAwaitEventName> = BridgePostEventsMap[E]['result'];
export {};
